@@ -9,7 +9,7 @@ use Exporter ();
 # @EXPORT_OK/%EXPORT_TAGS are set up in XS
 *import = \&Exporter::import;
 
-our $VERSION = '0.41_05'; # TRIAL VERSION
+our $VERSION = '0.41_06'; # TRIAL VERSION
 
 XSLoader::load(__PACKAGE__);
 
@@ -75,7 +75,11 @@ sub _dump {
 }
 
 sub _stack_trace {
-    my (undef, $filename, $line) = caller(0);
+    my ($package, $filename, $line);
+    for (my $level = 0; $level < 4; ++$level) {
+        ($package, $filename, $line) = caller($level);
+        last if $package ne __PACKAGE__;
+    }
 
     return "$filename line $line";
 }
@@ -94,7 +98,7 @@ Google::ProtocolBuffers::Dynamic - fast and complete protocol buffer implementat
 
 =head1 VERSION
 
-version 0.41_05
+version 0.41_06
 
 =head1 SYNOPSIS
 
